@@ -1,5 +1,6 @@
-import sql
 import funcs
+from sql import *
+from sql import _q
 from data_src import *
 
 rcsid = "$Id: __init__.py,v 1.4 2007/01/09 09:05:33 thinker Exp $"
