@@ -1,8 +1,8 @@
 from sql import func_generic as generic
 
-def sum(generic):
+class sum(generic):
     pass
 
-def count(generic):
+class count(generic):
     pass
 
